@@ -955,6 +955,7 @@ sub _create_entry {
   $bibentry->set_field('rawdata', $e->print_s);
 
   my $entrytype = $e->type;
+  $bibentry->set_field('entrytype', fc($entrytype));
 
   # We put all the fields we find modulo field aliases into the object
   # validation happens later and is not datasource dependent
@@ -987,11 +988,10 @@ sub _create_entry {
       }
     }
     elsif (Biber::Config->getoption('validate_datamodel')) {
-      biber_warn("Datamodel: Entry '$k' ($ds): Field '$f' invalid in data model - ignoring", $bibentry);
+      biber_warn("Datamodel: $entrytype entry '$k' ($ds): Field '$f' invalid in data model - ignoring", $bibentry);
     }
   }
 
-  $bibentry->set_field('entrytype', fc($entrytype));
   $bibentry->set_field('datatype', 'bibtex');
   if ($logger->is_debug()) {# performance tune
     $logger->debug("Adding entry with key '$k' to entry list");
@@ -1103,9 +1103,9 @@ sub _literal {
   if ($fc eq 'month') {
     return _hack_month($value);
   }
-  # Rationalise any bcp47 style langids into babel/polyglossia names
-  # biblatex will convert these back again when loading .lbx files
-  # We need this until babel/polyglossia support proper bcp47 language/locales
+  # Rationalise any BCP47 style langids into babel/polyglossia names
+  # We need this until babel/polyglossia support proper BCP47 language/locales and then
+  # biblatex needs to be changed as currently .lbx filenames are not BCP47 compliant
   elsif ($fc eq 'langid' and my $map = $LOCALE_MAP_R{$value}) {
     return $map;
   }
@@ -1306,6 +1306,7 @@ sub _datetime {
   my $secnum = $Biber::MASTER->get_current_section;
   my $section = $Biber::MASTER->sections->get_section($secnum);
   my $ds = $section->get_keytods($key);
+  my $bee = $bibentry->get_field('entrytype');
 
   my ($sdate, $edate, $sep, $unspec) = parse_date_range($bibentry, $datetype, $date);
 
@@ -1388,7 +1389,7 @@ sub _datetime {
     if ($sep) {
       if (defined($edate)) { # End date was successfully parsed
         if ($edate) { # End date is an object not "0"
-          # Did this entry get its datepart fields from splitting an EDTF date field?
+          # Did this entry get its datepart fields from splitting an ISO8601-2 date field?
           $bibentry->set_field("${datetype}datesplit", 1);
 
           unless ($CONFIG_DATE_PARSERS{end}->missing('year')) {
@@ -1430,12 +1431,12 @@ sub _datetime {
         }
       }
       else {
-        biber_warn("Entry '$key' ($ds): Invalid format '$date' of end date field '$field' - ignoring", $bibentry);
+        biber_warn("$bee entry '$key' ($ds): Invalid format '$date' of end date field '$field' - ignoring", $bibentry);
       }
     }
   }
   else {
-    biber_warn("Entry '$key' ($ds): Invalid format '$date' of date field '$field' - ignoring", $bibentry);
+    biber_warn("$bee entry '$key' ($ds): Invalid format '$date' of date field '$field' - ignoring", $bibentry);
   }
   return;
 }
@@ -1522,24 +1523,23 @@ sub cache_data {
       push $cache->{preamble}{$filename}->@*, $entry->value;
       next;
     }
-
     # Save comments for output in tool mode unless comment stripping is requested
-    if ( $entry->metatype == BTE_COMMENT ) {
+    elsif ( $entry->metatype == BTE_COMMENT ) {
       if (Biber::Config->getoption('tool') and not
           Biber::Config->getoption('strip_comments') ) {
         push $cache->{comments}{$filename}->@*, process_comment($entry->value);
       }
       next;
     }
-
     # Record macros in T::B so we can output then properly in tool mode
-    if ($entry->metatype == BTE_MACRODEF) {
+    elsif ($entry->metatype == BTE_MACRODEF) {
       foreach my $f ($entry->fieldlist) {
         $RSTRINGS{$entry->get($f)} = $f;
       }
       next;
     }
 
+
     # Ignore misc BibTeX entry types we don't care about
     next if ( $entry->metatype == BTE_UNKNOWN );
 
@@ -2054,7 +2054,7 @@ L<https://github.com/plk/biber/issues>.
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009-2012 François Charette and Philip Kime, all rights reserved.
-Copyright 2012-2022 Philip Kime, all rights reserved.
+Copyright 2012-2023 Philip Kime, all rights reserved.
 
 This module is free software.  You can redistribute it and/or
 modify it under the terms of the Artistic License 2.0.
