@@ -1433,7 +1433,7 @@ sub parse_date_end {
 
 =head2 parse_date
 
-  Parse of EDTF dates
+  Parse of iso8601-2 dates
 
 =cut
 
@@ -1937,7 +1937,7 @@ L<https://github.com/plk/biber/issues>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2012-2022 Philip Kime, all rights reserved.
+Copyright 2012-2023 Philip Kime, all rights reserved.
 
 This module is free software.  You can redistribute it and/or
 modify it under the terms of the Artistic License 2.0.
